/* Copyright (c) 1992, 1998 John E. Davis
 * This file is part of JED editor library source.
 *
 * You may distribute this file under the terms the GNU General Public
 * License.  See the file COPYING for more information.
 */
#ifndef _JED_SIG_H_
#define _JED_SIG_H_

#ifndef __MSDOS_16BIT__
extern void init_signals (void);
#endif
extern int Stdin_Is_TTY;

#ifdef __unix__
# ifdef SIGTSTP
extern void sig_sys_spawn_cmd(int);
extern int Signal_Sys_Spawn_Flag;      /* used if something else sends stop */
# endif
#endif

#endif /* _JED_SIG_H_ */
